<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja" sourcelanguage="en">
  <context>
    <name>AboutDialogBase</name>
    <message>
      <location filename="src/AboutDialogBase.ui" line="38"/>
      <source>About Synergy</source>
      <translation>Synergyについて</translation>
    </message>
    <message>
      <location filename="src/AboutDialogBase.ui" line="140"/>
      <location filename="src/AboutDialogBase.ui" line="174"/>
      <source>Unknown</source>
      <translation>不明</translation>
    </message>
    <message>
      <location filename="src/AboutDialogBase.ui" line="124"/>
      <source>Version:</source>
      <translation>バージョン:</translation>
    </message>
    <message>
      <location filename="src/AboutDialogBase.ui" line="53"/>
      <source>&lt;p&gt;
Keyboard and mouse sharing application. Cross platform and open source.&lt;br /&gt;&lt;br /&gt;
Copyright © 2012-2019 Symless Ltd.&lt;br /&gt;
Copyright © 2002-2012 Chris Schoeneman, Nick Bolton, Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Synergy is released under the GNU General Public License (GPLv2).&lt;br /&gt;&lt;br /&gt;
Synergy is based on CosmoSynergy by Richard Lee and Adam Feder.&lt;br /&gt;
The Synergy GUI is based on QSynergy by Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Visit our website for help and info (symless.com).
&lt;/p&gt;</source>
      <translation>&lt;p&gt;
キーボードとマウスの共有ソフトウェアです。クロスプラットフォームでオープンソースです。&lt;br /&gt;&lt;br /&gt;
Copyright © 2012-2019 Symless Ltd.&lt;br /&gt;
Copyright © 2002-2012 Chris Schoeneman, Nick Bolton, Volker Lanz.&lt;br /&gt;&lt;br /&gt;
Synergy は GNU General Public (GPLv2). のライセンスで公開されています。&lt;br /&gt;&lt;br /&gt;
Synergy のベースは CosmoSynergy (Richard Lee, Adam Feder 開発) です。&lt;br /&gt;
Synergy の GUI は QSynergy (Volker Lanz 開発) がベースです。&lt;br /&gt;&lt;br /&gt;
私たちのウェブサイトには情報とサポートがあります(symless.com)。
&lt;/p&gt;</translation>
    </message>
    <message>
      <location filename="src/AboutDialogBase.ui" line="167"/>
      <source>Build Date: </source>
      <translation>ビルド日: </translation>
    </message>
    <message>
      <location filename="src/AboutDialogBase.ui" line="194"/>
      <source>&amp;Ok</source>
      <translation>OK</translation>
    </message>
  </context>
  <context>
    <name>ActionDialogBase</name>
    <message>
      <location filename="src/ActionDialogBase.ui" line="14"/>
      <source>Configure Action</source>
      <translation>アクションの設定</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="20"/>
      <source>Choose the action to perform</source>
      <translation>実行するアクションを選択</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="26"/>
      <source>Press a hotkey</source>
      <translation>ホットキーを押す</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="36"/>
      <source>Release a hotkey</source>
      <translation>ホットキーを離す</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="43"/>
      <source>Press and release a hotkey</source>
      <translation>ホットキーを押して離す</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="69"/>
      <source>only on these screens</source>
      <translation>これらのモニターのみにする</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="119"/>
      <source>Switch to screen</source>
      <translation>モニターを切り替え</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="150"/>
      <source>Switch in direction</source>
      <translation>切り替える方向</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="174"/>
      <source>left</source>
      <translation>左</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="179"/>
      <source>right</source>
      <translation>右</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="184"/>
      <source>up</source>
      <translation>上</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="189"/>
      <source>down</source>
      <translation>下</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="201"/>
      <source>Lock cursor to screen</source>
      <translation>カーソルを画面に限定</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="225"/>
      <source>toggle</source>
      <translation>切り替え</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="230"/>
      <source>on</source>
      <translation>オン</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="235"/>
      <source>off</source>
      <translation>オフ</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="247"/>
      <source>Restart server</source>
      <translation>サーバーを再起動</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="259"/>
      <source>This action is performed when</source>
      <translation>このアクション実行のタイミング</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="265"/>
      <source>the hotkey is pressed</source>
      <translation>ホットキーを押したとき</translation>
    </message>
    <message>
      <location filename="src/ActionDialogBase.ui" line="275"/>
      <source>the hotkey is released</source>
      <translation>ホットキーを離したとき</translation>
    </message>
  </context>
  <context>
    <name>ActivationDialog</name>
    <message>
      <location filename="src/ActivationDialog.ui" line="14"/>
      <source>Activate Synergy</source>
      <translation>Synergy の認証</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.ui" line="26"/>
      <source>Serial key</source>
      <translation>シリアルキー</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.ui" line="33"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This can be found on your &lt;a href=&quot;https://symless.com/account/?source=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;account&lt;/span&gt;&lt;/a&gt; page.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;これは、あなたの&lt;a href=&quot;https://symless.com/account/?source=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;アカウント&lt;/span&gt;&lt;/a&gt;ページで確認できます。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.ui" line="49"/>
      <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.ui" line="88"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Your trial has expired. &lt;a href=&quot;http://symless.com/pricing?src=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Buy now!&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;試用の期限が切れています。&lt;a href=&quot;http://symless.com/pricing?src=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;すぐに購入&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.cpp" line="36"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Your trial has expired. &lt;a href=&quot;https://symless.com/synergy/trial/thanks?id=%1&quot;&gt;&lt;span style=&quot;text-decoration: underline; color:#0000ff;&quot;&gt;Buy now!&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;試用の期限が切れています。 &lt;a href=&quot;https://symless.com/synergy/trial/thanks?id=%1&quot;&gt;&lt;span style=&quot;text-decoration: underline; color:#0000ff;&quot;&gt;すぐに購入&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.cpp" line="77"/>
      <source>An error occurred while trying to activate Synergy. Please contact the helpdesk, and provide the following information:

%1</source>
      <translation>Synergy の認証中にエラーが発生しました。以下の情報を添えて、ヘルプデスクにお問い合わせください:

%1</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.cpp" line="86"/>
      <source>%1</source>
      <translation>%1</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.cpp" line="95"/>
      <source>Thanks for trying %1! %5

%2 day%3 of your trial remain%4</source>
      <translation>%1をお試しいただきありがとうございます! %5

あと %2 日試用できます</translation>
    </message>
    <message>
      <location filename="src/ActivationDialog.cpp" line="114"/>
      <source>Thanks for activating %1!</source>
      <translation>%1 認証していただきありがとうございます!</translation>
    </message>
  </context>
  <context>
    <name>AddClientDialog</name>
    <message>
      <location filename="src/AddClientDialogBase.ui" line="20"/>
      <source>Dialog</source>
      <translation>ダイアログ</translation>
    </message>
    <message>
      <location filename="src/AddClientDialogBase.ui" line="35"/>
      <source>TextLabel</source>
      <translation>TextLabel</translation>
    </message>
    <message>
      <location filename="src/AddClientDialogBase.ui" line="83"/>
      <source>Ignore auto connect clients</source>
      <translation>クライアントの自動接続を無視</translation>
    </message>
  </context>
  <context>
    <name>CancelActivationDialog</name>
    <message>
      <location filename="src/CancelActivationDialog.ui" line="14"/>
      <source>Cancel Activation</source>
      <translation>認証をキャンセル</translation>
    </message>
    <message>
      <location filename="src/CancelActivationDialog.ui" line="20"/>
      <source>Are you sure?

If you don&apos;t activate Synergy you&apos;ll be missing out on some great features.</source>
      <translation>確認

Synergy を認証しない場合、一部のさらなる機能は利用できません。</translation>
    </message>
    <message>
      <location filename="src/CancelActivationDialog.ui" line="35"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://symless.com/pricing?source=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Buy now&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://symless.com/pricing?source=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;すぐに購入&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
  </context>
  <context>
    <name>FailedLoginDialog</name>
    <message>
      <location filename="src/FailedLoginDialog.ui" line="14"/>
      <source>Activation Error</source>
      <translation>認証エラー</translation>
    </message>
    <message>
      <location filename="src/FailedLoginDialog.ui" line="42"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://symless.com/account/reset/?source=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Forgotten your password?&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://symless.com/account/reset/?source=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;パスワードをお忘れですか？&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/FailedLoginDialog.ui" line="58"/>
      <source>An error occurred while trying to activate Synergy. The Symless server returned the following error:

%1</source>
      <translation>Synergy の認証中にエラーが発生しました。Symless のサーバーから以下のエラーが返ってきました:

%1</translation>
    </message>
  </context>
  <context>
    <name>HotkeyDialogBase</name>
    <message>
      <location filename="src/HotkeyDialogBase.ui" line="14"/>
      <source>Hotkey</source>
      <translation>ホットキー</translation>
    </message>
    <message>
      <location filename="src/HotkeyDialogBase.ui" line="20"/>
      <source>Enter the specification for the hotkey:</source>
      <translation>ホットキーを入力してください:</translation>
    </message>
  </context>
  <context>
    <name>MainWindow</name>
    <message>
      <location filename="src/MainWindow.cpp" line="1000"/>
      <source>&amp;Start</source>
      <translation>開始(&amp;S)</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="284"/>
      <source>&amp;File</source>
      <translation>ファイル(&amp;F)</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="285"/>
      <source>&amp;Edit</source>
      <translation>編集(&amp;E)</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="286"/>
      <source>&amp;Window</source>
      <translation>ウィンドウ(&amp;W)</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="287"/>
      <source>&amp;Help</source>
      <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="432"/>
      <source>&lt;p&gt;Your version of Synergy is out of date. Version &lt;b&gt;%1&lt;/b&gt; is now available to &lt;a href=&quot;%2&quot;&gt;download&lt;/a&gt;.&lt;/p&gt;</source>
      <oldsource>&lt;p&gt;Version %1 is now available, &lt;a href=&quot;%2&quot;&gt;visit website&lt;/a&gt;.&lt;/p&gt;</oldsource>
      <translation>&lt;p&gt;お使いの Synergy は最新版ではありません。バージョン &lt;b&gt;%1&lt;/b&gt; が &lt;a href=&quot;%2&quot;&gt;ダウンロード&lt;/a&gt; できます。&lt;/p&gt;</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="494"/>
      <source>Synergy is now connected. You can close the config window and Synergy will remain connected in the background.</source>
      <translation>ただいま Synergy は接続されました。設定ウインドウを閉じることができます。それでもバックグラウンドで接続を維持します。</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="546"/>
      <source>You are connecting to a server. Here is it&apos;s fingerprint:

%1

Compare this fingerprint to the one on your server&apos;s screen.If the two don&apos;t match exactly, then it&apos;s probably not the server you&apos;re expecting (it could be a malicious user).

To automatically trust this fingerprint for future connections, click Yes. To reject this fingerprint and disconnect from the server, click No.</source>
      <translation>サーバーに接続しています。そのフィンガープリント:

%1

このフィンガープリントを、サーバー側のモニタに表示されているフィンガープリントとで確認してください。その2つが一致しない場合、接続したいサーバーではありません (悪意のあるサーバの可能性があります)。

「はい」で、今後の接続でも、このフィンガープリントを自動的に信頼します。「いいえ」で、このフィンガープリントを拒否しサーバーから接続を切断します。</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="722"/>
      <source>Program can not be started</source>
      <translation>プログラムを開始できません</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="722"/>
      <source>The executable&lt;br&gt;&lt;br&gt;%1&lt;br&gt;&lt;br&gt;could not be successfully started, although it does exist. Please check if you have sufficient permissions to run this program.</source>
      <translation>実行ファイル&lt;br&gt;&lt;br&gt;%1&lt;br&gt;&lt;br&gt;は存在しますが、開始できませんでした。このプログラムを動作させる十分な権限があるかどうか確認してください。</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="761"/>
      <source>Synergy client not found</source>
      <translation>Synergy のクライアントが見つかりません</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="762"/>
      <source>The executable for the synergy client does not exist.</source>
      <translation>のクライアントの実行ファイルが存在しません。</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="789"/>
      <source>No server selected</source>
      <translation>サーバーが選択されていません</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="790"/>
      <source>No auto config server was selected, try manual mode instead.</source>
      <translation>自動構成のサーバーが選択されていません。代わりに手動で試してください。</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="805"/>
      <source>Hostname is empty</source>
      <translation>ホスト名が空です</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="806"/>
      <source>Please fill in a hostname for the synergy client to connect to.</source>
      <translation>Synergy のクライアントが接続するホスト名を入力してください。</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="831"/>
      <source>Cannot write configuration file</source>
      <translation>構成ファイルに書き込めません</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="831"/>
      <source>The temporary configuration file required to start synergy can not be written.</source>
      <translation>Synergy の開始に必要な一時的な構成ファイルを書き込めません。</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="844"/>
      <source>Configuration filename invalid</source>
      <translation>構成ファイルのファイル名が正しくありません。</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="845"/>
      <source>You have not filled in a valid configuration file for the synergy server. Do you want to browse for the configuration file now?</source>
      <translation>Synergy のサーバー用の正しい構成ファイルではありません。構成ファイルを開きますか?</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="873"/>
      <source>Synergy server not found</source>
      <translation>Synergy のサーバーが見つかりません</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="874"/>
      <source>The executable for the synergy server does not exist.</source>
      <translation>Synergy のサーバーの実行ファイルが存在しません。</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="993"/>
      <source>&amp;Stop</source>
      <translation>停止(&amp;S)</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1016"/>
      <source>Synergy is waiting for clients</source>
      <translation>Synergy はクライアントの接続を待機中</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1023"/>
      <source>Synergy is connected (with %1)</source>
      <translation>Synergy 接続中 (%1 に接続)</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1026"/>
      <source>Synergy is running (without TLS encryption)</source>
      <translation>Synergy 実行中 (TLS暗号化なし)</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1031"/>
      <source>Synergy is starting...</source>
      <translation>Synergy 開始中...</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1034"/>
      <source>There was an error, retrying...</source>
      <translation>エラーです。再試行中...</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1037"/>
      <source>Synergy is not running</source>
      <translation>Synergy は動作していません</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1354"/>
      <source>Please add the server (%1) to the grid.</source>
      <translation>グリッドにサーバー  (%1) を追加してください。</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1360"/>
      <source>Please drag the new client screen (%1) to the desired position on the grid.</source>
      <translation>グリッド上の希望する位置に新しいクライアントのモニタ (%1) をドラッグしてください。</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1093"/>
      <source>Unknown</source>
      <translation>不明</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1247"/>
      <source>Browse for a synergys config file</source>
      <translation>Synergy の構成ファイルを参照</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="545"/>
      <source>Security question</source>
      <translation>セキュリティの質問</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1260"/>
      <source>Save configuration as...</source>
      <translation>構成設定に名前をつけて保存</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1264"/>
      <source>Save failed</source>
      <translation>保存できませんでした</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="1264"/>
      <source>Could not save configuration to file.</source>
      <translation>設定をファイルに保存できませんでした</translation>
    </message>
  </context>
  <context>
    <name>MainWindowBase</name>
    <message>
      <location filename="src/MainWindowBase.ui" line="26"/>
      <source>Synergy</source>
      <translation>Synergy</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="216"/>
      <source>Ser&amp;ver (share this computer&apos;s mouse and keyboard):</source>
      <translation>サーバー (このコンピューターのキーボードとマウスを共有する)(&amp;V):</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="525"/>
      <location filename="src/MainWindowBase.ui" line="562"/>
      <source>&amp;Start</source>
      <translation>開始(&amp;S)</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="307"/>
      <source>Use existing configuration:</source>
      <translation>既存の構成設定を使用:</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="58"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;%1&lt;/span&gt; days of your Synergy Pro trial remain. &lt;a href=&quot;http://symless.com/pricing?src=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Buy now!&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;%1&lt;/span&gt; 日間、Synergy Pro 版を試用できます。 &lt;a href=&quot;http://symless.com/pricing?src=gui&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;すぐに購入&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="257"/>
      <source>SSL Fingerprint:</source>
      <translation>SSL フィンガープリント</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="316"/>
      <source>&amp;Configuration file:</source>
      <translation>設定ファイル(&amp;C):</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="336"/>
      <source>&amp;Browse...</source>
      <translation>参照</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="273"/>
      <source>Configure interactively:</source>
      <translation>手動で構成を設定:</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="285"/>
      <source>&amp;Configure Server...</source>
      <translation>サーバーを設定</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="369"/>
      <source>Client name:</source>
      <translation>クライアント名:</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="383"/>
      <source>&amp;Server:</source>
      <translation>サーバー(&amp;S):</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="405"/>
      <source>Hostname or IP address of the server computer.</source>
      <translation>サーバーのパソコンのホスト名やIPアドレス。</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="428"/>
      <source>Server:</source>
      <translation>サーバー:</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="495"/>
      <source>Ready</source>
      <translation>準備完了</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="438"/>
      <source>Log</source>
      <translation>ログ</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="518"/>
      <source>&amp;Apply</source>
      <translation>適用(&amp;A)</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="233"/>
      <source>IP addresses:</source>
      <translation>IPアドレス:</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="354"/>
      <source>&amp;Client (use another computer&apos;s mouse and keyboard):</source>
      <translation>クライアント (ほかのコンピューターのマウスとキーボードを使う)(&amp;C):</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="535"/>
      <source>&amp;About Synergy...</source>
      <translation>Synergy について(&amp;A)...</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="543"/>
      <source>Visit &amp;help site</source>
      <translation>ヘルプサイトにアクセス(&amp;H)</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="551"/>
      <source>&amp;Quit</source>
      <translation>終了(&amp;Q)</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="554"/>
      <source>Quit</source>
      <translation>終了(&amp;Q)</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="565"/>
      <source>Run</source>
      <translation>開始(&amp;S)</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="576"/>
      <source>S&amp;top</source>
      <translation>停止(&amp;S)</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="579"/>
      <source>Stop</source>
      <translation>停止(&amp;S)</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="587"/>
      <source>S&amp;how Status</source>
      <translation>状態を表示(&amp;S)</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="595"/>
      <source>&amp;Hide</source>
      <translation>隠す(&amp;H)</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="598"/>
      <source>Hide</source>
      <translation>隠す(&amp;H)</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="606"/>
      <source>&amp;Show</source>
      <translation>表示(&amp;S)</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="609"/>
      <source>Show</source>
      <translation>表示(&amp;S)</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="617"/>
      <source>Save configuration &amp;as...</source>
      <translation>構成設定に名前をつけて保存(&amp;A)...</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="620"/>
      <source>Save the interactively generated server configuration to a file.</source>
      <translation>手動で設定したサーバーの構成をファイルに保存する.
</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="628"/>
      <source>Settings</source>
      <translation>設定</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="631"/>
      <source>Edit settings</source>
      <translation>設定を編集</translation>
    </message>
    <message>
      <location filename="src/MainWindowBase.ui" line="639"/>
      <location filename="src/MainWindowBase.ui" line="642"/>
      <source>Activate</source>
      <translation>認証</translation>
    </message>
  </context>
  <context>
    <name>NewScreenWidget</name>
    <message>
      <location filename="src/NewScreenWidget.cpp" line="32"/>
      <source>Unnamed</source>
      <translation>名前なし</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="src/MainWindow.cpp" line="62"/>
      <source>Synergy Configurations (*.sgc);;All files (*.*)</source>
      <translation>Synergy 構成設定 (*.sgc);;すべてのファイル(*.*)</translation>
    </message>
    <message>
      <location filename="src/MainWindow.cpp" line="65"/>
      <source>Synergy Configurations (*.conf);;All files (*.*)</source>
      <translation>Synergy 構成設定 (*.conf);;すべてのファイル(*.*)</translation>
    </message>
    <message>
      <location filename="src/main.cpp" line="138"/>
      <source>System tray is unavailable, don&apos;t close your window.</source>
      <translation>システムトレイが利用できないためウィンドウを閉じないように。</translation>
    </message>
  </context>
  <context>
    <name>ScreenSettingsDialog</name>
    <message>
      <location filename="src/ScreenSettingsDialog.cpp" line="67"/>
      <source>Screen name is empty</source>
      <translation>モニター名がありません</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialog.cpp" line="68"/>
      <source>The screen name cannot be empty. Please either fill in a name or cancel the dialog.</source>
      <translation>モニター名を空にはできません。名前を入力するか、ダイアログをキャンセルしてください。</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialog.cpp" line="83"/>
      <source>Screen name matches alias</source>
      <translation>モニター名は別名に一致</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialog.cpp" line="84"/>
      <source>The screen name cannot be the same as an alias. Please either remove the alias or change the screen name.</source>
      <translation>モニター名を別名と同じにできません。別名を削除するか、モニター名を変更してください。</translation>
    </message>
  </context>
  <context>
    <name>ScreenSettingsDialogBase</name>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="14"/>
      <source>Screen Settings</source>
      <translation>モニターの設定</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="22"/>
      <source>Screen &amp;name:</source>
      <translation>モニター名(&amp;N):</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="42"/>
      <source>A&amp;liases</source>
      <translation>別名(&amp;A)</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="57"/>
      <source>&amp;Add</source>
      <translation>追加(&amp;A)</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="74"/>
      <source>&amp;Remove</source>
      <translation>除去(&amp;R)</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="97"/>
      <source>&amp;Modifier keys</source>
      <translation>修飾キー(&amp;M)</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="106"/>
      <source>&amp;Shift:</source>
      <translation>Shift(&amp;S):</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="117"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="164"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="211"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="258"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="305"/>
      <source>Shift</source>
      <translation>Shift</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="122"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="169"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="216"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="263"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="310"/>
      <source>Ctrl</source>
      <translation>Ctrl</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="127"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="174"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="221"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="268"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="315"/>
      <source>Alt</source>
      <translation>Alt</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="132"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="179"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="226"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="273"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="320"/>
      <source>Meta</source>
      <translation>メタ</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="137"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="184"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="231"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="278"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="325"/>
      <source>Super</source>
      <translation>スーパー</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="142"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="189"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="236"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="283"/>
      <location filename="src/ScreenSettingsDialogBase.ui" line="330"/>
      <source>None</source>
      <translation>なし</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="150"/>
      <source>&amp;Ctrl:</source>
      <translation>Ctrl (&amp;C):</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="197"/>
      <source>Al&amp;t:</source>
      <translation>Alt (&amp;T):</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="244"/>
      <source>M&amp;eta:</source>
      <translation>メタ (&amp;E):</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="291"/>
      <source>S&amp;uper:</source>
      <translation>スーパー (&amp;S):</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="358"/>
      <source>&amp;Dead corners</source>
      <translation>無効とする隅(&amp;D)</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="367"/>
      <source>Top-left</source>
      <translation>左上</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="374"/>
      <source>Top-right</source>
      <translation>右上</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="381"/>
      <source>Bottom-left</source>
      <translation>左下</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="388"/>
      <source>Bottom-right</source>
      <translation>右下</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="397"/>
      <source>Corner Si&amp;ze:</source>
      <translation>隅の大きさ(&amp;Z):</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="428"/>
      <source>&amp;Fixes</source>
      <translation>修正(&amp;F)</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="437"/>
      <source>Fix CAPS LOCK key</source>
      <translation>CAPS ロックキーを固定</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="444"/>
      <source>Fix NUM LOCK key</source>
      <translation>NUM ロックキーを固定</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="451"/>
      <source>Fix SCROLL LOCK key</source>
      <translation>SCROLL ロックキーを固定</translation>
    </message>
    <message>
      <location filename="src/ScreenSettingsDialogBase.ui" line="458"/>
      <source>Fix XTest for Xinerama</source>
      <translation>Xinerama 向けに XTest を修正</translation>
    </message>
  </context>
  <context>
    <name>ScreenSetupModel</name>
    <message>
      <location filename="src/ScreenSetupModel.cpp" line="51"/>
      <source>&lt;center&gt;Screen: &lt;b&gt;%1&lt;/b&gt;&lt;/center&gt;&lt;br&gt;Double click to edit settings&lt;br&gt;Drag screen to the trashcan to remove it</source>
      <translation>&lt;center&gt;画面: &lt;b&gt;%1&lt;/b&gt;&lt;/center&gt;&lt;br&gt;ダブルクリックで設定を編集&lt;br&gt;削除するときは画面をゴミ箱にドラッグします</translation>
    </message>
  </context>
  <context>
    <name>ServerConfigDialog</name>
    <message>
      <location filename="src/ServerConfigDialog.cpp" line="83"/>
      <source>Configure server</source>
      <translation>サーバーの構成設定</translation>
    </message>
  </context>
  <context>
    <name>ServerConfigDialogBase</name>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="14"/>
      <source>Server Configuration</source>
      <translation>サーバーの構成設定</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="24"/>
      <source>Screens and links</source>
      <translation>モニタの結びつき</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="35"/>
      <source>Drag a screen from the grid to the trashcan to remove it.</source>
      <translation>削除するには、グリッド内のモニターをゴミ箱にドラッグしてください。</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="60"/>
      <source>Configure the layout of your synergy server configuration.</source>
      <translation>Synergy のサーバー構成の配置を設定します。</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="73"/>
      <source>Drag this button to the grid to add a new screen.</source>
      <translation>新規モニターの追加するには、このボタンをグリッド内にドラッグします。</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="128"/>
      <source>Drag new screens to the grid or move existing ones around.
Drag a screen to the trashcan to delete it.
Double click on a screen to edit its settings.</source>
      <translation>新規モニターをグリッド内にドラッグするか、既存のモニターを移動してください。
削除するには、モニターをゴミ箱にドラッグします。
モニターの設定を編集するには、モニターをダブルクリックします。</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="157"/>
      <source>Hotkeys</source>
      <translation>ホットキー</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="163"/>
      <source>&amp;Hotkeys</source>
      <translation>ホットキー</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="175"/>
      <source>&amp;New</source>
      <translation>新規(&amp;N)</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="185"/>
      <source>&amp;Edit</source>
      <translation>編集(&amp;E)</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="195"/>
      <source>&amp;Remove</source>
      <translation>削除</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="218"/>
      <source>A&amp;ctions</source>
      <translation>アクション(&amp;A)</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="230"/>
      <source>Ne&amp;w</source>
      <translation>新規</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="240"/>
      <source>E&amp;dit</source>
      <translation>編集(&amp;D)</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="250"/>
      <source>Re&amp;move</source>
      <translation>除去(&amp;M)</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="274"/>
      <source>Advanced server settings</source>
      <translation>サーバーの詳細設定</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="280"/>
      <source>&amp;Switch</source>
      <translation>切り替え(&amp;S)</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="291"/>
      <source>Switch &amp;after waiting</source>
      <translation>次の時間の後切り替え(&amp;A)</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="330"/>
      <location filename="src/ServerConfigDialogBase.ui" line="383"/>
      <location filename="src/ServerConfigDialogBase.ui" line="552"/>
      <source>ms</source>
      <translation>ミリ秒</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="344"/>
      <source>Switch on double &amp;tap within</source>
      <translation>次の時間内のダブルタップで切り替え(&amp;T)</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="408"/>
      <source>&amp;Options</source>
      <translation>オプション(&amp;O)</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="416"/>
      <source>Enable clipboard sharing</source>
      <translation>クリップボードを共有</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="452"/>
      <source>MB</source>
      <translation>MB</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="461"/>
      <source>Enable drag and drop file transfers</source>
      <translation>ドラッグアンドドロップでファイル転送</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="513"/>
      <source>&amp;Check clients every</source>
      <translation>クライアント確認頻度(&amp;C)</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="481"/>
      <source>Use &amp;relative mouse moves</source>
      <translation>相対的なマウスの移動を使用(&amp;R)</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="564"/>
      <source>S&amp;ynchronize screen savers</source>
      <translation>スクリーンセーバーの同期(&amp;Y)</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="471"/>
      <source>Don&apos;t take &amp;foreground window on Windows servers</source>
      <translation>Windows サーバ上ではウィンドウを前面に表示しない(&amp;F)</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="501"/>
      <source>Ignore auto config clients</source>
      <translation>自動構成のクライアントを無視</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="571"/>
      <source>Disable lock to screen</source>
      <translation>画面ロックを無効化</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="581"/>
      <source>&amp;Dead corners</source>
      <translation>無効とする隅(&amp;D)</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="590"/>
      <source>To&amp;p-left</source>
      <translation>左上(&amp;P)</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="597"/>
      <source>Top-rig&amp;ht</source>
      <translation>右上(&amp;H)</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="604"/>
      <source>&amp;Bottom-left</source>
      <translation>左下(&amp;B)</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="611"/>
      <source>Bottom-ri&amp;ght</source>
      <translation>右下(&amp;G)</translation>
    </message>
    <message>
      <location filename="src/ServerConfigDialogBase.ui" line="633"/>
      <source>Cor&amp;ner Size:</source>
      <translation>隅の大きさ(&amp;N):</translation>
    </message>
  </context>
  <context>
    <name>SettingsDialog</name>
    <message>
      <location filename="src/SettingsDialog.cpp" line="184"/>
      <source>Save log file to...</source>
      <translation>ログファイルの保存先</translation>
    </message>
  </context>
  <context>
    <name>SettingsDialogBase</name>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="14"/>
      <source>Settings</source>
      <translation>設定</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="21"/>
      <source>&amp;Settings Scope</source>
      <translation>設定スコープ(&amp;S)</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="27"/>
      <source>System</source>
      <translation>システム</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="37"/>
      <source>User</source>
      <translation>ユーザー</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="59"/>
      <source>Sc&amp;reen name:</source>
      <translation>モニター名(&amp;R):</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="76"/>
      <source>P&amp;ort:</source>
      <translation>ポート(&amp;O):</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="105"/>
      <source>&amp;Interface:</source>
      <translation>インターフェース(&amp;I):</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="147"/>
      <source>Specify when the Synergy service should run at an elevated privilege level</source>
      <translation>Synergy のサービスを昇格した権限で実行するタイミングの指定</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="154"/>
      <source>As Needed</source>
      <translation>必要に応じて</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="159"/>
      <source>Always</source>
      <translation>常に</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="164"/>
      <source>Never</source>
      <translation>なし</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="172"/>
      <source>Elevate</source>
      <translation>権限昇格</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="186"/>
      <source>Minimize to System &amp;Tray</source>
      <translation>システムトレイに最小化(&amp;T)</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="221"/>
      <source>&amp;Network</source>
      <translation>ネットワーク(&amp;N)</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="253"/>
      <source>Enable &amp;TLS Encryption</source>
      <translation>TLS 暗号化を有効(&amp;T)</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="263"/>
      <source>Enable Auto Config</source>
      <translation>自動構成を有効</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="270"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;#&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;Install Bonjour&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;#&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;Bonjour をインストール&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="280"/>
      <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://symless.com/account?source=gui&amp;amp;intent=upgrade&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;Upgrade to Pro&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
      <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://symless.com/account?source=gui&amp;intent=upgrade&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;Pro 版にアップグレード&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="179"/>
      <source>&amp;Hide on startup</source>
      <translation>起動時に隠す(&amp;H)</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="320"/>
      <source>Logging</source>
      <translation>ログ記録</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="338"/>
      <source>&amp;Logging level:</source>
      <translation>ログレベル:</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="372"/>
      <source>Log to file:</source>
      <translation>ログ記録先ファイル:</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="389"/>
      <source>Browse...</source>
      <translation>参照...</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="134"/>
      <source>&amp;Language:</source>
      <translation>言語(&amp;L):</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="47"/>
      <source>&amp;Miscellaneous</source>
      <translation>その他(&amp;M)</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="349"/>
      <source>Info</source>
      <translation>情報</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="354"/>
      <source>Debug</source>
      <translation>デバッグ情報</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="359"/>
      <source>Debug1</source>
      <translation>デバッグ情報1</translation>
    </message>
    <message>
      <location filename="src/SettingsDialogBase.ui" line="364"/>
      <source>Debug2</source>
      <translation>デバッグ情報2</translation>
    </message>
  </context>
  <context>
    <name>SetupWizard</name>
    <message>
      <location filename="src/SetupWizard.cpp" line="65"/>
      <source>Setup Synergy</source>
      <translation>Synergy のセットアップ</translation>
    </message>
    <message>
      <location filename="src/SetupWizard.cpp" line="75"/>
      <source>Please select an option.</source>
      <translation>オプションを選択してください。</translation>
    </message>
  </context>
  <context>
    <name>SetupWizardBase</name>
    <message>
      <location filename="src/SetupWizardBase.ui" line="26"/>
      <source>Setup Synergy</source>
      <translation>Synergy のセットアップ</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="30"/>
      <source>Welcome</source>
      <translation>ようこそ</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="39"/>
      <source>Thanks for installing Synergy!</source>
      <translation>Synergy をインストールしていただき、ありがとうございます！</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="114"/>
      <source>Synergy lets you easily share your mouse and keyboard between multiple computers on your desk, and it&apos;s Free and Open Source. Just move your mouse off the edge of one computer&apos;s screen on to another. You can even share all of your clipboards. All you need is a network connection. Synergy is cross-platform (works on Windows, Mac OS X and Linux).</source>
      <translation>Synergy によって、複数のデスクトップパソコン間でマウスとキーボードを簡単に共有することができます。そしてこれは無料でオープンソースのソフトウェアです。あるコンピュータの画面の端にマウスを移動するだけで、別のコンピュータの画面に移ることができます。クリップボードを共有することもできます。必要なのはネットワーク接続だけです。 Synergy はクロスプラットフォームで Windows, Mac OS X, Linux で動作します。</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="159"/>
      <source>My main mouse and keyboard are connected to this computer. This will allow you to move your mouse over to another computer&apos;s screen. There can only be one server in your setup.</source>
      <translation>メインのマウスとキーボードはこのパソコンに接続されています。このことで、ほかのパソコンのモニタへとマウスカーソルを移動できます。サーバーは1つだけ設定できます。</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="204"/>
      <source>You have already set up a server. This computer will be controlled using the server&apos;s mouse and keyboard. There can be many clients in your setup.</source>
      <translation>サーバーはすでに設定されています。サーバーのマウスとキーボードを使ってこのパソコンを制御できます。クライアントは複数設定できます。</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="146"/>
      <source>&amp;Server (share this computer&apos;s mouse and keyboard)</source>
      <translation>サーバー (このコンピューターのキーボードとマウスを共有する)(&amp;V)</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="191"/>
      <source>&amp;Client (use another computer&apos;s mouse and keyboard)</source>
      <translation>クライアント (ほかのコンピューターのマウスとキーボードを使う)(&amp;C)</translation>
    </message>
    <message>
      <location filename="src/SetupWizardBase.ui" line="131"/>
      <source>Server or Client?</source>
      <translation>サーバーにしますか？またはクライアントですか？</translation>
    </message>
  </context>
  <context>
    <name>SslCertificate</name>
    <message>
      <location filename="src/SslCertificate.cpp" line="46"/>
      <source>Failed to get profile directory.</source>
      <translation>プロファイルのフォルダ取得に失敗しました。</translation>
    </message>
    <message>
      <location filename="src/SslCertificate.cpp" line="148"/>
      <source>SSL certificate generated.</source>
      <translation>SSL 証明書を生成しました。</translation>
    </message>
    <message>
      <location filename="src/SslCertificate.cpp" line="178"/>
      <source>SSL fingerprint generated.</source>
      <translation>SSL フィンガープリントを生成しました。</translation>
    </message>
    <message>
      <location filename="src/SslCertificate.cpp" line="181"/>
      <source>Failed to find SSL fingerprint.</source>
      <translation>SSL フィンガープリントが見つかりませんでした。</translation>
    </message>
  </context>
  <context>
    <name>VersionChecker</name>
    <message>
      <location filename="src/VersionChecker.cpp" line="145"/>
      <source>Unknown</source>
      <translation>不明</translation>
    </message>
  </context>
  <context>
    <name>ZeroconfService</name>
    <message>
      <location filename="src/ZeroconfService.cpp" line="82"/>
      <source>zeroconf server detected: %1</source>
      <translation>ゼロ構成のサーバーを検出: %1</translation>
    </message>
    <message>
      <location filename="src/ZeroconfService.cpp" line="91"/>
      <source>zeroconf client detected: %1</source>
      <translation>ゼロ構成のクライアントを検出: %1</translation>
    </message>
    <message>
      <location filename="src/ZeroconfService.cpp" line="100"/>
      <location filename="src/ZeroconfService.cpp" line="132"/>
      <location filename="src/ZeroconfService.cpp" line="143"/>
      <source>Synergy Auto Config</source>
      <translation>Synergy 自動構成</translation>
    </message>
    <message>
      <location filename="src/ZeroconfService.cpp" line="133"/>
      <source>Unable to start zeroconf: %1.</source>
      <translation>ゼロ構成は開始できません: %1</translation>
    </message>
    <message>
      <location filename="src/ZeroconfService.cpp" line="101"/>
      <source>Error code: %1.</source>
      <translation>エラーコード: %1</translation>
    </message>
    <message>
      <location filename="src/ZeroconfService.cpp" line="144"/>
      <source>Failed to get local IP address. Please manually type in server address on your clients</source>
      <translation>ローカル IP アドレスの取得に失敗しました。クライアント上でサーバーのアドレスを手動で入力してください</translation>
    </message>
    <message>
      <location filename="src/ZeroconfService.cpp" line="150"/>
      <location filename="src/ZeroconfService.cpp" line="157"/>
      <source>%1</source>
      <translation>%1</translation>
    </message>
  </context>
</TS>
